@@ -18,33 +18,36 @@
 */
 
 #include "kchatdialog.h"
+#include "kfourinline_debug.h"
 
 #define USE_UNSTABLE_LIBKDEGAMESPRIVATE_API
 #include <libkdegamesprivate/kchatbase.h>
 
+#include <KConfigGroup>
 #include <KLocalizedString>
-#include <qfontdialog.h>
-#include "kfourinline_debug.h"
-#include <klineedit.h>
 
-#include <QLayout>
-#include <QLabel>
-#include <QPushButton>
+#include <QDialogButtonBox>
+#include <QFontDialog>
 #include <QFrame>
+#include <QGridLayout>
+#include <QLabel>
+#include <QLayout>
+#include <QLineEdit>
+#include <QPushButton>
 
 class KChatDialogPrivate
 {
  public:
 	KChatDialogPrivate()
 	{
-		mTextPage = 0;
+		mTextPage = nullptr;
 
-		mNamePreview = 0;
-		mTextPreview = 0;
-		mSystemNamePreview = 0;
-		mSystemTextPreview = 0;
+		mNamePreview = nullptr;
+		mTextPreview = nullptr;
+		mSystemNamePreview = nullptr;
+		mSystemTextPreview = nullptr;
 
-		mChat = 0;
+		mChat = nullptr;
 	}
 
 	QFrame* mTextPage;
@@ -54,31 +57,26 @@ class KChatDialogPrivate
 	QLabel* mSystemNamePreview;
 	QLabel* mSystemTextPreview;
 
-	KLineEdit* mMaxMessages;
+	QLineEdit* mMaxMessages;
 
 	KChatBase* mChat;
 };
 
 KChatDialog::KChatDialog(KChatBase* chat, QWidget* parent, bool modal) 
-    : KDialog(parent),
+    : QDialog(parent),
       d( new KChatDialogPrivate )
 {
- setCaption(i18n("Configure Chat"));
- setButtons(Ok|Default|Apply|Cancel);
  setModal(modal);
  init();
  plugChatWidget(chat);
 }
 
 KChatDialog::KChatDialog(QWidget* parent, bool modal) 
-    : KDialog(parent),
+    : QDialog(parent),
       d( new KChatDialogPrivate )
 {
- setCaption(i18n("Configure Chat"));
- setButtons(Ok|Default|Apply|Cancel);
  setModal(modal);
  init();
-//  init();
 }
 
 KChatDialog::~KChatDialog()
@@ -89,9 +87,19 @@ KChatDialog::~KChatDialog()
 void KChatDialog::init()
 {
  d->mTextPage = new QFrame( this );
- setMainWidget( d->mTextPage );
  QGridLayout* layout = new QGridLayout(d->mTextPage);
 
+ setWindowTitle(i18n("Configure Chat"));
+ buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok|QDialogButtonBox::Cancel|QDialogButtonBox::Apply);
+ QWidget *mainWidget = new QWidget(this);
+ setLayout(layout);
+ layout->addWidget(mainWidget);
+ QPushButton *okButton = buttonBox->button(QDialogButtonBox::Ok);
+ okButton->setDefault(true);
+ okButton->setShortcut(Qt::CTRL | Qt::Key_Return);
+ connect(buttonBox, &QDialogButtonBox::accepted, this, &KChatDialog::accept);
+ connect(buttonBox, &QDialogButtonBox::rejected, this, &KChatDialog::reject);
+
 // General fonts
  QPushButton* nameFont = new QPushButton(i18n("Name Font..."), d->mTextPage);
  connect(nameFont, &QPushButton::pressed, this, &KChatDialog::slotGetNameFont);
@@ -135,11 +143,13 @@ void KChatDialog::init()
 // message count
  QLabel* maxMessages = new QLabel(i18n("Maximum number of messages (-1 = unlimited):"), d->mTextPage);
  layout->addWidget(maxMessages, 6, 0);
- d->mMaxMessages = new KLineEdit(d->mTextPage);
+ d->mMaxMessages = new QLineEdit(d->mTextPage);
  d->mMaxMessages->setText(QString::number(-1));
  layout->addWidget(d->mMaxMessages, 6, 1);
- connect(this, &KChatDialog::applyClicked, this, &KChatDialog::slotApply);
- connect(this, &KChatDialog::okClicked, this, &KChatDialog::slotOk);
+
+ layout->addWidget(buttonBox, 7, 0, 1, 2);
+ connect(buttonBox->button(QDialogButtonBox::Apply), &QPushButton::clicked, this, &KChatDialog::slotApply);
+ connect(okButton, &QPushButton::clicked, this, &KChatDialog::slotOk);
 }
 
 void KChatDialog::slotGetNameFont()
@@ -229,7 +239,7 @@ void KChatDialog::configureChatWidget(KChatBase* widget)
 void KChatDialog::slotOk()
 {
  slotApply();
- KDialog::accept();
+ QDialog::accept();
 }
 
 void KChatDialog::slotApply()
